@@ -274,8 +274,23 @@ class JsonList(list):
 
         return self.filter(d["criteria"])
 
+    def split_by(self, m) -> dict:
+        if type(m) is str:
+            d = {}
+            exec("def criteria(i): return i.%s" % m, d)
+            m = d["criteria"]
+
+        r = {}
+        for i in self:
+            l = m(i)
+            if l not in r:
+                r[l] = self.__class__()
+                self.list_type = self.list_type
+            r[l].append(i)
+        return r
+
     def filter(self, l):
-        nl = type(self)()
+        nl = self.__class__()
         for i in self:
             if l(i):
                 nl.append(i)
@@ -288,7 +303,7 @@ class JsonList(list):
         return nl
 
     def copy(self):
-        return type(self).parse(str(self))
+        return self.__class__.parse(str(self))
 
     @classorinstancemethod
     def parse(cls_or_self, json_string="", json_list=None):
